@@ -17,7 +17,7 @@ class Cookie(object):
 
     See rfc2109, HTTP State Management Mechanism
 
-    Example::
+    Example:
 
         >>> from fresco.cookie import Cookie
         >>> c = Cookie('session_id', 'abc123')
@@ -101,15 +101,16 @@ class Cookie(object):
 
 def expire_cookie(cookie_or_name, *args, **kwargs):
     """
-    Synopsis::
+    Synopsis:
 
         >>> from fresco import Response
+        >>> from fresco.cookie import expire_cookie
         >>> def view():
         ...     return Response(set_cookie=expire_cookie('X', path='/'))
         ...
         >>> from fresco import FrescoApp
         >>> with FrescoApp().requestcontext() as c:
-        ...     print view().get_header('Set-Cookie')
+        ...     print(view().get_header('Set-Cookie'))
         ...
         X=;Expires=Tue, 01 Jan 1980 00:00:00 -0000;Max-Age=0;Path=/;Version=1
     """
