@@ -140,7 +140,7 @@ class RequestArg(RouteArg):
                             self.exception('No value provided for %s' %
                                            (self.formkey,)))
             else:
-                value = self.default
+                return self.default
 
         try:
             if self.converter is not None:
