@@ -144,7 +144,7 @@ class Converter(object):
         Convert string argument ``s`` to the target object representation,
         whatever that may be.
         """
-        raise NotImplementedError
+        return s
 
 
 class IntConverter(Converter):
@@ -697,7 +697,7 @@ class Route(object):
                                  pattern=self.pattern.add_prefix(path))
         return newroute
 
-    def path(self, request=None, *args, **kwargs):
+    def path(self, *args, **kwargs):
         """\
         Return a tuple of URL path component corresponding to the route and
         remaining positional and keyword arguments
@@ -705,6 +705,7 @@ class Route(object):
         Positional and keywords arguments are forwarded to the ``pathfor``
         method of the pattern.
         """
+        request = kwargs.pop('request', None)
         for k in self.routed_args_default:
             if k not in kwargs:
                 v = self.routed_args_default[k]
@@ -728,6 +729,17 @@ class Route(object):
         if func_ob is not None:
             yield func_ob
 
+    def decorate(self, *decorators):
+        """
+        Add a decorator into the route. Can be chained for a fluid api::
+
+            Route('/user/<id:int>', GET, edituser)\
+                    .decorate(require_ssl)
+                    .decorate(logged_in)
+        """
+        self.decorators.extend(decorators)
+        return self
+
 
 def split_iter(pattern, string):
     """
@@ -789,7 +801,7 @@ class RouteCollection(object):
             # See http://www.python.org/dev/peps/pep-0232/
             pass
 
-    def pathfor(self, viewspec, request=None, *args, **kwargs):
+    def pathfor(self, viewspec, *args, **kwargs):
         """\
         Return the path component of the url for the given view name/function
         spec.
@@ -798,6 +810,7 @@ class RouteCollection(object):
                          ``'package.module.viewfunction'``, or the view
                          callable itself.
         """
+        request = kwargs.pop('request', None)
         if isinstance(viewspec, string_types) and ':' in viewspec:
             viewspec, remainder = viewspec.split(':', 1)
             delegated_route = self.routefor(viewspec)
@@ -1062,3 +1075,21 @@ class DelegateRoute(Route):
 
     def _static_routecollectionfactory(self, *args, **kwargs):
         return self.getview()
+
+
+def register_converter(name, registry=ExtensiblePattern):
+    """
+    Class decorator that registers a converter class for use with
+    ExtensiblePattern.
+
+    Example::
+
+        >>> @register_converter('hex')
+        ... class HexStringConverter(Converter):
+        ...     pattern = r'[a-f0-9]+'
+        ...
+    """
+    def register_converter(cls):
+        registry.register_converter(name, cls)
+        return cls
+    return register_converter
