@@ -1,9 +1,6 @@
-from flea import TestAgent
-from nose.tools import assert_equal, assert_raises
-
 from fresco import FrescoApp, GET, Response
 from fresco.decorators import extract_getargs
-from fresco.exceptions import BadRequest
+
 
 class TestExtractGetArgs(object):
 
@@ -15,57 +12,55 @@ class TestExtractGetArgs(object):
         @extract_getargs(arg1=str, arg2=int)
         def handler(arg1, arg2):
             return Response([
-                'Received %r:%s, %r:%s' % (arg1, type(arg1).__name__, arg2, type(arg2).__name__)
+                'Received %r:%s, %r:%s' % (arg1, type(arg1).__name__,
+                                           arg2, type(arg2).__name__)
             ])
 
-        assert_equal(
-            TestAgent(app).get('/foo/29').body,
-            "Received 'foo':str, 29:int"
-        )
+        with app.requestcontext('/foo/29'):
+            assert app.view().content == ["Received 'foo':str, 29:int"]
 
     def test_query_args(self):
 
         @extract_getargs(arg1=str, arg2=int)
         def view(arg1, arg2):
             return Response([
-                'Received %r:%s, %r:%s' % (arg1, type(arg1).__name__, arg2, type(arg2).__name__)
+                'Received %r:%s, %r:%s' % (arg1, type(arg1).__name__,
+                                           arg2, type(arg2).__name__)
             ])
 
         app = FrescoApp()
         app.route('/', GET, view)
-        assert_equal(
-            TestAgent(app).get('/?arg1=foo;arg2=29').body,
-            "Received 'foo':str, 29:int"
-        )
+        with app.requestcontext('/?arg1=foo;arg2=29'):
+            assert app.view().content == ["Received 'foo':str, 29:int"]
 
     def test_missing_args_with_one_default_argument(self):
 
         @extract_getargs(arg1=str, arg2=int)
         def view(arg1, arg2):
             return Response([
-                'Received %r:%s, %r:%s' % (arg1, type(arg1).__name__, arg2, type(arg2).__name__)
+                'Received %r:%s, %r:%s' % (arg1, type(arg1).__name__,
+                                           arg2, type(arg2).__name__)
             ])
 
         app = FrescoApp()
         app.route('/', GET, view)
-        assert_equal(
-            TestAgent(app).get('/?arg1=foo', check_status=False).response.status_code,
-            400
-        )
+        with app.requestcontext('/?arg1=foo'):
+            assert app.view().status_code == 400
 
     def test_missing_args(self):
 
         @extract_getargs(arg1=str, arg2=int)
         def view(arg1, arg2=None):
             return Response([
-                'Received %r:%s, %r:%s' % (arg1, type(arg1).__name__, arg2, type(arg2).__name__)
+                'Received %r:%s, %r:%s' % (arg1, type(arg1).__name__,
+                                           arg2, type(arg2).__name__)
             ])
 
         app = FrescoApp()
         app.route('/', GET, view)
-        r = TestAgent(app).get('/?arg1=foo')
-        assert_equal(r.response.status, '200 OK')
-        assert_equal(r.body, "Received 'foo':str, None:NoneType")
+        with app.requestcontext('/?arg1=foo'):
+            assert app.view().status == '200 OK'
+            assert app.view().content == ["Received 'foo':str, None:NoneType"]
 
     def test_conversion_error_without_default(self):
 
@@ -75,7 +70,8 @@ class TestExtractGetArgs(object):
 
         app = FrescoApp()
         app.route('/', GET, view)
-        assert_equal(TestAgent(app).get('/?arg1=foo', check_status=False).response.status_code, 400)
+        with app.requestcontext('/?arg1=foo'):
+            assert app.view().status_code == 400
 
     def test_conversion_error_with_strict_checking(self):
 
@@ -87,7 +83,8 @@ class TestExtractGetArgs(object):
 
         app = FrescoApp()
         app.route('/', GET, view)
-        assert_equal(TestAgent(app).get('/?arg1=foo', check_status=False).response.status_code, 400)
+        with app.requestcontext('/?arg1=foo'):
+            assert app.view().status_code == 400
 
     def test_no_conversion_error_with_default(self):
 
@@ -99,5 +96,5 @@ class TestExtractGetArgs(object):
 
         app = FrescoApp()
         app.route('/', GET, view)
-        assert_equal(TestAgent(app).get('/?arg1=foo').body, 'Received None:NoneType')
-
+        with app.requestcontext('/?arg1=foo'):
+            assert app.view().content == ['Received None:NoneType']
