@@ -107,6 +107,15 @@ class TestPathEncoding(object):
 
 class TestMakeURL(object):
 
+    def assert_equal_with_query(self, url1, url2):
+        if '?' not in url1:
+            return assert_equal(url1, url2)
+
+        base1, _, q1 = url1.partition('?')
+        base2, _, q2 = url2.partition('?')
+        assert_equal(base1, base2)
+        assert_equal(sorted(q1.split(';')), sorted(q2.split(';')))
+
     def test_it_returns_request_url(self):
         with context(SCRIPT_NAME='/script', PATH_INFO='/pathinfo') as c:
             assert_equal(c.request.make_url(),
@@ -139,13 +148,15 @@ class TestMakeURL(object):
 
     def test_query_dict(self):
         with context() as c:
-            assert_equal(c.request.make_url(query={'a': 1, 'b': '2 3'}),
-                         'http://localhost/?a=1;b=2+3')
+            self.assert_equal_with_query(
+                c.request.make_url(query={'a': 1, 'b': '2 3'}),
+                'http://localhost/?a=1;b=2+3')
 
     def test_query_kwargs(self):
         with context() as c:
-            assert_equal(c.request.make_url(query={'a': 1}, b=2),
-                         'http://localhost/?a=1;b=2')
+            self.assert_equal_with_query(
+                c.request.make_url(query={'a': 1}, b=2),
+                'http://localhost/?a=1;b=2')
 
     def test_unicode_path(self):
         e = b'\xc3\xa9'.decode('utf8')  # e-acute
@@ -177,13 +188,15 @@ class TestMakeURL(object):
 
     def test_replace_query_adds_new_value(self):
         with context(QUERY_STRING='a=1') as c:
-            assert_equal(c.request.make_url(query_replace={'b': '2'}),
-                         'http://localhost/?a=1;b=2')
+            self.assert_equal_with_query(
+                c.request.make_url(query_replace={'b': '2'}),
+                'http://localhost/?a=1;b=2')
 
     def test_add_query_doesnt_replace_existing(self):
         with context(QUERY_STRING='a=1') as c:
-            assert_equal(c.request.make_url(query_add={'a': '2'}),
-                         'http://localhost/?a=1;a=2')
+            self.assert_equal_with_query(
+                c.request.make_url(query_add={'a': '2'}),
+                'http://localhost/?a=1;a=2')
 
     def test_add_query_works_on_specified_query(self):
         with context(QUERY_STRING='a=1') as c:
