@@ -83,6 +83,14 @@ class TestRouteArg(object):
             app.view()
             view.assert_called_with(x='d')
 
+    def test_it_doesnt_convert_default_values(self):
+        view = Mock()
+        app = FrescoApp()
+        app.route('/', GET, view, x=routeargs.FormArg(int, default=None))
+        with app.requestcontext('/'):
+            app.view()
+            view.assert_called_with(x=None)
+
     def test_access_to_missing_requestarg_returns_badrequest(self):
         def view(x):
             x == 0
