@@ -58,6 +58,20 @@ class TestRouteDecorators(object):
         with app.requestcontext('/plain'):
             assert app.view().content == ['test']
 
+    def test_decorator_is_applied_with_decorate_method(self):
+
+        views = fixtures.CBV('test')
+
+        app = FrescoApp()
+        app.route('/decorated', GET, views.index_html).decorate(self.exclaim)
+        app.route('/plain', GET, views.index_html)
+
+        with app.requestcontext('/decorated'):
+            assert app.view().content == ['test!']
+
+        with app.requestcontext('/plain'):
+            assert app.view().content == ['test']
+
     def test_decorator_works_with_urlfor(self):
 
         views = fixtures.CBV('test')
@@ -168,6 +182,11 @@ class TestRouteCollection(object):
                                            (a, '/rabbit/hole'),
                                            (b, '/rabbit/hole/rabbit')]
 
+    def test_pathfor_works_with_positional_args(self):
+        view = Mock()
+        rc = RouteCollection([Route('/<:str>', GET, view)])
+        assert rc.pathfor(view, 'x') == '/x'
+
 
 class TestRoutefor(object):
 
@@ -395,6 +414,22 @@ class TestConverters(object):
         s = ustring_type('abc')
         assert isinstance(StrConverter().from_string(s), ustring_type)
 
+    def test_register_coverter_acts_as_decorator(self):
+        from fresco.routing import Converter, register_converter
+
+        @register_converter('testconverter')
+        class MyConverter(Converter):
+            def from_string(self, s):
+                return 'bar'
+
+        view = Mock()
+
+        app = FrescoApp()
+        app.route('/<:testconverter>', GET, view)
+        with app.requestcontext('/foo'):
+            app.view()
+            assert view.call_args == (('bar',), {}), view.call_args
+
 
 class TestViewArgs(object):
 
