@@ -41,7 +41,7 @@ class TestNormPath(object):
 class TestMakeQuery(object):
 
     def test_make_query(self):
-        assert make_query(a='1', b=2) == 'a=1;b=2'
+        assert sorted(make_query(a='1', b=2).split(';')) == ['a=1', 'b=2']
         assert make_query(a='one two three') == 'a=one+two+three'
         assert make_query(a=['one', 'two', 'three']) == 'a=one;a=two;a=three'
 
