@@ -1,8 +1,9 @@
-"""
-Utility functions for HTTP message parsing
+#
+# Copyright (c) 2009-2014 Oliver Cope. All rights reserved.
+# See LICENSE.txt for terms of redistribution and use.
 
-Copyright (c) 2009-2012 Oliver Cope. All rights reserved.
-See LICENSE.txt for terms of redistribution and use.
+"""
+Utilities for working with data on the HTTP level
 """
 
 import re
@@ -52,8 +53,9 @@ class MissingContentLength(RequestParseError):
 
 def dequote(s):
     """\
-    Return ``s`` with surrounding quotes removed. Example usage::
+    Return ``s`` with surrounding quotes removed. Example usage:
 
+        >>> from fresco.util.http import dequote
         >>> dequote('foo')
         'foo'
         >>> dequote('"foo"')
@@ -77,13 +79,9 @@ def parse_header(header):
         ('multipart/form-data', {'boundary': '-------7d91772e200be'})
     """
     items = header.split(';')
-    pairs = [
-        (name, dequote(value))
-             for name, value in (
-                 item.lstrip().split('=', 1)
-                    for item in items[1:]
-            )
-    ]
+    pairs = [(name, dequote(value))
+             for name, value in (item.lstrip().split('=', 1)
+                                 for item in items[1:])]
     return (items[0], dict(pairs))
 
 
@@ -131,7 +129,7 @@ def parse_querystring(data, charset=None, strict=False, keep_blank_values=True,
         try:
             yield (unquote(key), unquote(value))
         except UnicodeDecodeError:
-            raise RequestParseError("Invalid character data: can't decode"\
+            raise RequestParseError("Invalid character data: can't decode"
                                     " as %r" % (charset,))
 
 
@@ -178,7 +176,7 @@ def parse_post(environ, fp, default_charset=None, max_size=16 * KB,
         try:
             boundary = ct_params['boundary']
         except KeyError:
-            raise RequestParseError("No boundary given in multipart/form-data"\
+            raise RequestParseError("No boundary given in multipart/form-data"
                                     " content-type")
         return parse_multipart(SizeLimitedInput(fp, content_length),
                                boundary.encode('ascii'), charset, max_size)
@@ -211,13 +209,13 @@ def parse_multipart(fp, boundary, default_charset, max_size):
 
     boundary_size = len(boundary)
     if not boundary.startswith(b'--'):
-        raise RequestParseError("Malformed boundary string:"\
-                                " must start with '--' (rfc 2046)")
+        raise RequestParseError("Malformed boundary string: "
+                                "must start with '--' (rfc 2046)")
 
     if boundary_size > 72:
-        raise RequestParseError("Malformed boundary string:"\
-                                " must be no more than 70 characters, not"\
-                                " counting the two leading hyphens (rfc 2046)")
+        raise RequestParseError("Malformed boundary string: "
+                                "must be no more than 70 characters, not "
+                                "counting the two leading hyphens (rfc 2046)")
 
     assert boundary_size + 2 < CHUNK_SIZE, \
           "CHUNK_SIZE cannot be smaller than the boundary string"
@@ -243,8 +241,8 @@ def parse_multipart(fp, boundary, default_charset, max_size):
         try:
             name = params['name']
         except KeyError:
-            raise RequestParseError("Missing name parameter in"\
-                                    " Content-Disposition header")
+            raise RequestParseError("Missing name parameter in "
+                                    "Content-Disposition header")
 
         is_file_upload = 'Content-Type' in headers and 'filename' in params
 
@@ -262,14 +260,14 @@ def parse_multipart(fp, boundary, default_charset, max_size):
                 data.seek(0)
                 yield name, data.read().decode(charset)
             except UnicodeDecodeError:
-                raise RequestParseError("Invalid character data: can't decode"\
-                                        " as %r" % (charset,))
+                raise RequestParseError("Invalid character data: can't decode "
+                                        "as %r" % (charset,))
 
         chunk = fp.read(2)
         if chunk == b'--':
             if fp.peek(3) != b'\r\n':
-                raise RequestParseError("Expected terminating CRLF"\
-                                        " at end of stream")
+                raise RequestParseError("Expected terminating CRLF "
+                                        "at end of stream")
             break
 
         if chunk != b'\r\n':
